@@ -52,7 +52,7 @@ static int pidfile_add_path(struct iwatch *iw, char *path)
 			ptr = slash++;
 			slash = strchr(ptr, '/');
 			if (slash) {
-				dbg("Path too deep, skipping.");
+				dbg("Path too deep, skipping %s", path);
 				return -1;
 			}
 		}
@@ -66,6 +66,7 @@ static void pidfile_update_conds(char *dir, char *name, uint32_t mask)
 	char cond[MAX_COND_LEN];
 	char fn[PATH_MAX];
 	svc_t *svc;
+	char *nm;
 
 	paste(fn, sizeof(fn), dir, name);
 	if (fnmatch("*\\.pid", fn, 0) && fnmatch("*/pid", fn, 0))
@@ -79,9 +80,33 @@ static void pidfile_update_conds(char *dir, char *name, uint32_t mask)
 		return;
 	}
 
-	dbg("Found svc %s for %s with pid %d", svc_ident(svc, NULL, 0), fn, svc->pid);
+	switch (svc->state) {
+	case SVC_TEARDOWN_STATE:
+	case SVC_CLEANUP_STATE:
+	case SVC_SETUP_STATE:
+		/*
+		 * E.g., a setup script for a container may run in lieu
+		 * of crun, trying to fetch a container image from the
+		 * network.  This script may want to advertise its PID
+		 * to the system for clean and swift reboots.
+		 */
+		dbg("%s[%d]: ignoring any PID file changes in CLEANUP/TEARDOWN/SETUP",
+		    svc_ident(svc, NULL, 0), svc->pid);
+		return;
+	default:
+		break;
+	}
+
+	/* Service condistion to set/clear */
 	mkcond(svc, cond, sizeof(cond));
 
+	nm = svc_ident(svc, NULL, 0);
+	dbg("Found svc %s for %s with pid %d", nm, fn, svc->pid);
+	if (svc_is_stopping(svc)) {
+		dbg("Ignoring pidfile death rattles while service %s is %s", nm, svc_status(svc));
+		goto sneaky_zebra;
+	}
+
 	if (mask & (IN_CLOSE_WRITE | IN_ATTRIB | IN_MODIFY | IN_MOVED_TO)) {
 		/*
 		 * only mark native services as started, the s6 and
@@ -125,6 +150,7 @@ static void pidfile_update_conds(char *dir, char *name, uint32_t mask)
 		if (svc->notify == SVC_NOTIFY_PID || svc->notify == SVC_NOTIFY_NONE)
 			service_ready(svc, 1);
 	} else if (mask & IN_DELETE) {
+	sneaky_zebra:
 		cond_clear(cond);
 		if (svc->notify == SVC_NOTIFY_PID)
 			service_ready(svc, 0);
