@@ -1,6 +1,6 @@
 /* User-defined condition event monitor for the Finit condition engine
  *
- * Copyright (c) 2021  Joachim Wiberg <troglobit@gmail.com>
+ * Copyright (c) 2021-2024  Joachim Wiberg <troglobit@gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -52,7 +52,7 @@ static void usr_callback(void *arg, int fd, int events)
 
 	sz = read(fd, ev_buf, sizeof(ev_buf) - 1);
 	if (sz <= 0) {
-		_pe("invalid inotify event");
+		err(1, "invalid inotify event");
 		return;
 	}
 	ev_buf[sz] = 0;
@@ -65,7 +65,7 @@ static void usr_callback(void *arg, int fd, int events)
 		if (off + sizeof(*ev) + ev->len > (size_t)sz)
 			break;
 
-		_d("name %s, event: 0x%08x", ev->name, ev->mask);
+		dbg("name %s, event: 0x%08x", ev->name, ev->mask);
 		if (!ev->mask)
 			continue;
 
@@ -84,14 +84,15 @@ static void usr_init(void *arg)
 	char usrdir[MAX_ARG_LEN];
 	char *path;
 
+	mkpath(_PATH_COND, 0755);
 	if (mkpath(pid_runpath(_PATH_CONDUSR, usrdir, sizeof(usrdir)), 0755) && errno != EEXIST) {
-		_pe("Failed creating %s condition directory, %s", COND_USR, _PATH_CONDUSR);
+		err(1, "Failed creating %s condition directory, %s", COND_USR, _PATH_CONDUSR);
 		return;
 	}
 
 	path = realpath(_PATH_CONDUSR, NULL);
 	if (!path) {
-		_pe("Cannot figure out real path to %s, aborting", _PATH_CONDUSR);
+		err(1, "Cannot figure out real path to %s, aborting", _PATH_CONDUSR);
 		return;
 	}
 
@@ -104,6 +105,7 @@ static void usr_init(void *arg)
 static plugin_t plugin = {
 	.name = __FILE__,
 	.hook[HOOK_BASEFS_UP]  = { .cb = usr_init },
+	.depends = { "bootmisc", },
 };
 
 PLUGIN_INIT(plugin_init)
@@ -123,8 +125,8 @@ PLUGIN_INIT(plugin_init)
 
 PLUGIN_EXIT(plugin_exit)
 {
-	iwatch_exit(&iw_usr);
 	plugin_unregister(&plugin);
+	iwatch_exit(&iw_usr);
 }
 
 /**
