@@ -259,6 +259,11 @@ static void cgroup_events_cb(uev_t *w, void *arg, int events)
 	ssize_t sz;
 	size_t off;
 
+	if (UEV_ERROR == events) {
+		dbg("%s(): inotify socket %d invalid.", __func__, w->fd);
+		return;
+	}
+
 	sz = read(w->fd, ev_buf, sizeof(ev_buf) - 1);
 	if (sz <= 0) {
 		err(1, "invalid inotify event");
@@ -463,10 +468,15 @@ void cgroup_init(uev_ctx_t *ctx)
 	FILE *fp;
 	int fd;
 
+#ifndef CGROUP2_ENABLED
+	avail = 0;
+	return;
+#endif
+
 	if (mount("none", FINIT_CGPATH, "cgroup2", opts, NULL)) {
 		if (errno == ENOENT)
 			logit(LOG_INFO, "Kernel does not support cgroups v2, disabling.");
-		else if (errno == EPERM) /* Probably inside an unpriviliged container */
+		else if (errno == EPERM) /* Probably inside an unprivileged container */
 			logit(LOG_INFO, "Not allowed to mount cgroups v2, disabling.");
 		else
 			err(1, "Failed mounting cgroup v2");
