@@ -1,6 +1,6 @@
 /* External client API, using UNIX domain socket.
  *
- * Copyright (c) 2015-2021  Joachim Wiberg <troglobit@gmail.com>
+ * Copyright (c) 2015-2024  Joachim Wiberg <troglobit@gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -29,8 +29,12 @@
 
 int    client_connect          (void);
 int    client_disconnect       (void);
+int    client_socket           (void);
 
+int    client_request          (struct init_request *rq, ssize_t len);
 int    client_send             (struct init_request *rq, ssize_t len);
+int    client_command          (int cmd);
+
 svc_t *client_svc_iterator     (int first);
 svc_t *client_svc_find         (const char *arg);
 svc_t *client_svc_find_by_cond (const char *arg);
