@@ -1,6 +1,6 @@
 /* Parser for /etc/finit.conf and /etc/finit.d/<SVC>.conf
  *
- * Copyright (c) 2012-2021  Joachim Wiberg <troglobit@gmail.com>
+ * Copyright (c) 2012-2024  Joachim Wiberg <troglobit@gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -42,6 +42,10 @@ int  conf_any_change      (void);
 int  conf_changed         (char *file);
 int  conf_monitor         (void);
 
+void conf_reset_env       (void);
+void conf_saverc          (void);
+void conf_save_exec_order (svc_t *svc, char *cmdline, int result);
+void conf_save_service    (int type, char *cfg, char *file);
 void conf_parse_cmdline   (int argc, char *argv[]);
 int  conf_parse_runlevels (char *runlevels);
 void conf_parse_cond      (svc_t *svc, char *cond);
