@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021  Joachim Wiberg <troglobit@gmail.com>
+ * Copyright (c) 2018-2024  Joachim Wiberg <troglobit@gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -49,7 +49,6 @@ static int recreate(char *path, mode_t mode, uid_t uid, gid_t gid)
  */
 int logrotate(char *file, int num, off_t sz)
 {
-	int cnt;
 	struct stat st;
 
 	if (stat(file, &st))
@@ -60,6 +59,7 @@ int logrotate(char *file, int num, off_t sz)
 			size_t len = strlen(file) + 10 + 1;
 			char   ofile[len];
 			char   nfile[len];
+			int    cnt;
 
 			/* First age zipped log files */
 			for (cnt = num; cnt > 2; cnt--) {
@@ -97,8 +97,7 @@ int logrotate(char *file, int num, off_t sz)
 		} else {
 		fallback:
 			if (truncate(file, 0))
-				syslog(LOG_ERR, "Failed truncating %s during logrotate: %s",
-				       file, strerror(errno));
+				syslog(LOG_ERR, "Failed truncating %s: %s", file, strerror(errno));
 		}
 	}
 
