@@ -1,7 +1,7 @@
 /* PID and PID file helpers
  *
  * Copyright (c) 2008-2010  Claudio Matsuoka <cmatsuoka@gmail.com>
- * Copyright (c) 2008-2021  Joachim Wiberg <troglobit@gmail.com>
+ * Copyright (c) 2008-2024  Joachim Wiberg <troglobit@gmail.com>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -51,6 +51,7 @@ static inline char *pid_runpath(const char *file, char *path, size_t len)
 {
 	static char *prefix = "/var/run";
 	static int unknown = 1;
+	char *ptr;
 	int rc;
 
 	if (unknown) {
@@ -59,14 +60,13 @@ static inline char *pid_runpath(const char *file, char *path, size_t len)
 		unknown = 0;
 	}
 
-	if (!strncmp(file, "/var/run/", 9))
-		file += 9;
-	else if (!strncmp(file, "/run/", 5))
-		file += 5;
+	ptr = strstr(file, "/run/");
+	if (ptr)
+		file = ptr + 5;
 
 	rc = paste(path, len, prefix, file);
 	if (rc < 0 || (size_t)rc >= len)
-		_e("File path '%s' truncated, should end with '%s'", path, file);
+		err(1, "File path '%s' truncated, should end with '%s'", path, file);
 
 	return path;
 }
