@@ -52,14 +52,16 @@ typedef enum {
 } svc_type_t;
 
 #define SVC_TYPE_ANY          (-1)
-#define SVC_TYPE_RESPAWN      (SVC_TYPE_SERVICE | SVC_TYPE_TTY)
-#define SVC_TYPE_RUNTASK      (SVC_TYPE_RUN | SVC_TYPE_TASK | SVC_TYPE_SYSV)
+#define SVC_TYPE_RESPAWN      (SVC_TYPE_SERVICE | SVC_TYPE_SYSV | SVC_TYPE_TTY)
+#define SVC_TYPE_RUNTASK      (SVC_TYPE_RUN | SVC_TYPE_TASK)
 
 typedef enum {
 	SVC_HALTED_STATE = 0,	/* Not allowed in runlevel, or not enabled. */
 	SVC_DONE_STATE,		/* Task/Run job has been run */
+	SVC_DEAD_STATE,		/* Process is dead and scheduled for removal */
+	SVC_CLEANUP_STATE,	/* Running cleanup: script */
+	SVC_TEARDOWN_STATE,	/* Running post: script */
 	SVC_STOPPING_STATE,	/* Waiting to collect the child process */
-	SVC_CLEANUP_STATE,	/* Running post: script */
 	SVC_SETUP_STATE,	/* Running pre: script */
 	SVC_PAUSED_STATE,	/* Condition is in flux, process SIGSTOPed */
 	SVC_WAITING_STATE,	/* Enabled but condition not satisfied */
@@ -146,7 +148,7 @@ typedef struct svc {
 	char           cond[MAX_COND_LEN];
 
 	/* Instance specifics */
-	int            job;	       /* For intenal use only, canonical ref is NAME:ID */
+	int            job;	       /* For internal use only, canonical ref is NAME:ID */
 	char           name[MAX_ARG_LEN];
 	char           id[MAX_ID_LEN]; /* :ID */
 	char           ifstmt[MAX_IDENT_LEN];
@@ -196,9 +198,18 @@ typedef struct svc {
 	char           conflict[MAX_ARG_LEN];
 	char	       desc[MAX_STR_LEN];
 	char	       env[MAX_CMD_LEN];
+
 	char	       pre_script[MAX_CMD_LEN];
+	int	       pre_tmo;
+
 	char	       post_script[MAX_CMD_LEN];
+	int	       post_tmo;
+
 	char	       ready_script[MAX_CMD_LEN];
+	int	       ready_tmo;
+
+	char	       cleanup_script[MAX_CMD_LEN];
+	int	       cleanup_tmo;
 
 	/*
 	 * Used to forcefully kill services that won't shutdown on
@@ -237,6 +248,7 @@ void	    svc_foreach	           (int (*cb)(svc_t *));
 void        svc_foreach_type       (int types, int (*cb)(svc_t *));
 
 svc_t	   *svc_stop_completed	   (void);
+svc_t      *svc_clean_completed    (void);
 
 void	    svc_mark		   (svc_t *svc);
 void	    svc_mark_dynamic       (void);
@@ -259,6 +271,7 @@ static inline int svc_is_tty       (svc_t *svc) { return svc && SVC_TYPE_TTY
 static inline int svc_is_runtask   (svc_t *svc) { return svc && (SVC_TYPE_RUNTASK & svc->type);}
 static inline int svc_is_forking   (svc_t *svc) { return svc && svc->forking; }
 static inline int svc_is_manual    (svc_t *svc) { return svc && svc->manual; }
+static inline int svc_is_nohup     (svc_t *svc) { return svc && (0 == svc->sighup); }
 
 static inline int svc_in_runlevel  (svc_t *svc, int runlevel) { return svc && ISSET(svc->runlevels, runlevel); }
 static inline int svc_nohup        (svc_t *svc) { return svc &&  (0 == svc->sighup || 0 != svc->args_dirty); }
@@ -266,11 +279,14 @@ static inline int svc_has_pidfile  (svc_t *svc) { return svc_is_daemon(svc) && s
 static inline int svc_has_pre      (svc_t *svc) { return svc->pre_script[0];  }
 static inline int svc_has_post     (svc_t *svc) { return svc->post_script[0]; }
 static inline int svc_has_ready    (svc_t *svc) { return svc->ready_script[0];}
+static inline int svc_has_cleanup  (svc_t *svc) { return svc->cleanup_script[0]; }
 
 static inline void svc_starting    (svc_t *svc) { if (svc) svc->starting = 1;       }
 static inline void svc_started     (svc_t *svc) { if (svc) svc->starting = 0;       }
 static inline int  svc_is_starting (svc_t *svc) { return svc && 0 != svc->starting; }
 static inline int  svc_is_running  (svc_t *svc) { return svc && svc->state == SVC_RUNNING_STATE; }
+static inline int  svc_is_stopping (svc_t *svc) { return svc && svc->state == SVC_STOPPING_STATE; }
+static inline int  svc_is_stopped  (svc_t *svc) { return svc && svc->block == SVC_BLOCK_USER; }
 
 static inline int  svc_is_removed  (svc_t *svc) { return svc && svc->removed; }
 static inline int  svc_is_changed  (svc_t *svc) { return svc &&  0 != svc->dirty; }
@@ -385,12 +401,15 @@ static inline char *svc_status(svc_t *svc)
 			return "stopping";
 		}
 
-	case SVC_CLEANUP_STATE:
-		return "cleanup";
+	case SVC_TEARDOWN_STATE:
+		return "teardown";
 
 	case SVC_SETUP_STATE:
 		return "setup";
 
+	case SVC_CLEANUP_STATE:
+		return "cleanup";
+
 	case SVC_PAUSED_STATE:
 		return "paused";
 
@@ -403,6 +422,9 @@ static inline char *svc_status(svc_t *svc)
 	case SVC_RUNNING_STATE:
 		return "running";
 
+	case SVC_DEAD_STATE:
+		return "dead";
+
 	default:
 		return "UNKNOWN";
 	}
