@@ -1,6 +1,6 @@
 #!/bin/sh
 # Regression test for issue #351 - verify that a dirty run/task in
-# runlevel S is not restarted forever jus because it exits with a
+# runlevel S is not restarted forever just because it exits with a
 # non-zero error code.
 set -eu
 
@@ -42,8 +42,8 @@ test_one()
 
 sep
 say "Add stanza to $FINIT_CONF"
-run "echo 'run fail.sh -- Failure' > $FINIT_RCSD/fail.conf"
-run "echo 'run initctl touch fail' > $FINIT_RCSD/touch.conf"
+run "echo 'run /sbin/fail.sh -- Failure' > $FINIT_RCSD/fail.conf"
+run "echo 'run initctl touch fail'       > $FINIT_RCSD/touch.conf"
 test_one 2
 
 sep
